import { RequestType, Response, ErrorCodes, NotificationType } from './messages';
export { Response, ErrorCodes, RequestType, NotificationType };
export interface IRequestHandler<P, R extends Response> {
    (params?: P): R | Thenable<R>;
}
export interface INotificationHandler<P> {
    (params?: P): void;
}
export interface ILogger {
    error(message: string): any;
    warn(message: string): any;
    info(message: string): any;
    log(message: string): any;
}
export interface MessageConnection {
    sendNotification<P>(type: NotificationType<P>, params?: P): void;
    onRequest<P, R extends Response>(type: RequestType<P, R>, handler: IRequestHandler<P, R>): void;
    onNotification<P>(type: NotificationType<P>, handler: INotificationHandler<P>): void;
    dispose(): void;
}
export interface ServerMessageConnection extends MessageConnection {
}
export interface ClientMessageConnection extends MessageConnection {
    sendRequest<P, R extends Response>(type: RequestType<P, R>, params?: P): Thenable<R>;
}
export declare function createServerMessageConnection(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream, logger: ILogger): ServerMessageConnection;
export declare function createClientMessageConnection(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream, logger: ILogger): ClientMessageConnection;
