/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
var is = require('./is');
/**
 * Message kinds.
 */
var Message;
(function (Message) {
    /**
     * A request message usually send from the client to the server
     */
    Message.Request = 'request';
    /**
     * A message response usually send from the server to the client
     */
    Message.Response = 'response';
    /**
     * A event message usually send asynchronously from the server to the client
     */
    Message.Event = 'event';
})(Message = exports.Message || (exports.Message = {}));
/**
 * Predefined error codes.
 */
var ErrorCodes;
(function (ErrorCodes) {
    ErrorCodes.ParseError = -32700;
    ErrorCodes.InvalidRequest = -32600;
    ErrorCodes.MethodNotFound = -32601;
    ErrorCodes.InvalidParams = -32602;
    ErrorCodes.InternalError = -32603;
    ErrorCodes.serverErrorStart = -32099;
    ErrorCodes.serverErrorEnd = -32000;
})(ErrorCodes = exports.ErrorCodes || (exports.ErrorCodes = {}));
/**
 * Tests if the given message is a request message
 */
function isRequestMessage(message) {
    var candidate = message;
    return candidate && is.string(candidate.method) && (is.string(candidate.id) || is.number(candidate.id));
}
exports.isRequestMessage = isRequestMessage;
/**
 * Tests if the given message is a notification message
 */
function isNotificationMessage(message) {
    var candidate = message;
    return candidate && is.string(candidate.method) && is.undefined(message.id);
}
exports.isNotificationMessage = isNotificationMessage;
/**
 * Tests if the given message is a response message
 */
function isReponseMessage(message) {
    var candidate = message;
    return candidate && (is.defined(candidate.result) || is.defined(candidate.error)) && (is.string(candidate.id) || is.number(candidate.id));
}
exports.isReponseMessage = isReponseMessage;
function isResponse(value) {
    var candidate = value;
    return candidate && (is.defined(candidate.result) || is.defined(candidate.error));
}
exports.isResponse = isResponse;
function isFailedResponse(value) {
    var candidate = value;
    return candidate && is.defined(candidate.error) && is.undefined(candidate.result);
}
exports.isFailedResponse = isFailedResponse;
function isSuccessfulResponse(value) {
    var candidate = value;
    return candidate && is.defined(candidate.result) && is.undefined(candidate.error);
}
exports.isSuccessfulResponse = isSuccessfulResponse;
//# sourceMappingURL=messages.js.map